package CSS::Croco::Term;

use utf8;
use strict;
use warnings;
1;

__END__

=head1 NAME

CSS::Croco::Term - value of CSS property

=head1 DESCRIPTION

Abstract class, do not used directly

=head1 METHODS

=head2 get

Returns value

=head2 to_string

Returns string representation of value

=head1 BUGS

=head1 NOTES

=head1 AUTHOR

Andrey Kostenko (), <andrey@kostenko.name>

=head1 COMPANY

Rambler Internet Holding

=head1 CREATED

03.11.2009 02:47:42 MSK

=cut

use strict;
use warnings;



